@@ -1,7 +1,7 @@
 # @CODE:CORE-PROJECT-003 | SPEC: SPEC-CORE-PROJECT-001.md, SPEC-INIT-004.md
-# @CODE:INIT-004:VALIDATION | Chain: SPEC-INIT-004 -> CODE-INIT-004 -> TEST-INIT-004
-# @REQ:VALIDATION-001 | SPEC-INIT-004: Initial verification after installation completion
-# @SPEC:VERIFICATION-001 | SPEC-INIT-004: Verification logic implementation
+# @CODE:INIT-VALIDATOR-001:VALIDATION | Chain: SPEC-INIT-004 -> CODE-INIT-004 -> TEST-INIT-004
+# @REQ:VALIDATION-002 | SPEC-INIT-004: Initial verification after installation completion
+# @SPEC:VERIFICATION-002 | SPEC-INIT-004: Verification logic implementation
 """Project initialization validation module.
 
 Validates system requirements and installation results.
@@ -13,8 +13,8 @@ SPEC-INIT-004 Enhancement:
 
 TAG Chain:
   SPEC-INIT-004 (spec.md)
-    └─> @CODE:INIT-004:VALIDATION (this file)
-        └─> @TEST:INIT-004:VALIDATION (test_validator.py)
+    └─> @CODE:INIT-VALIDATOR-001:VALIDATION (this file)
+        └─> @TEST:INIT-005:VALIDATION (test_validator.py)
 """
 
 import shutil
@@ -98,9 +98,9 @@ class ProjectValidator:
     def validate_installation(self, project_path: Path) -> None:
         """Validate installation results.
 
-        @CODE:INIT-004:VERIFY-001 | Verification of all required files upon successful completion
-        @SPEC:VERIFICATION-001 | SPEC-INIT-004: Verification checklist implementation
-        @REQ:VALIDATION-001 | UR-003: All required files verified after init completes
+        @CODE:INIT-VALIDATOR-001:VERIFY-001 | Verification of all required files upon successful completion
+        @SPEC:VERIFICATION-002 | SPEC-INIT-004: Verification checklist implementation
+        @REQ:VALIDATION-002 | UR-003: All required files verified after init completes
 
         Args:
             project_path: Project path.
@@ -109,22 +109,22 @@ class ProjectValidator:
             ValidationError: Raised when installation was incomplete.
         """
         # Verify required directories
-        # @CODE:INIT-004:VALIDATION-001 | Core project structure validation
+        # @CODE:INIT-VALIDATOR-001:VALIDATION-001 | Core project structure validation
         for directory in self.REQUIRED_DIRECTORIES:
             dir_path = project_path / directory
             if not dir_path.exists():
                 raise ValidationError(f"Required directory not found: {directory}")
 
         # Verify required files
-        # @CODE:INIT-004:VALIDATION-002 | Required configuration files validation
+        # @CODE:INIT-VALIDATOR-001:VALIDATION-002 | Required configuration files validation
         for file in self.REQUIRED_FILES:
             file_path = project_path / file
             if not file_path.exists():
                 raise ValidationError(f"Required file not found: {file}")
 
-        # @CODE:INIT-004:VERIFY-002 | Verify required Alfred command files (SPEC-INIT-004)
+        # @CODE:INIT-VALIDATOR-001:VERIFY-002 | Verify required Alfred command files (SPEC-INIT-004)
         # @REQ:COMMAND-GENERATION-001 | All 4 Alfred command files must be created
-        # @CODE:INIT-004:ALFRED-VALIDATION | Alfred command file integrity check
+        # @CODE:INIT-VALIDATOR-001:ALFRED-VALIDATION | Alfred command file integrity check
         alfred_dir = project_path / ".claude" / "commands" / "alfred"
         missing_commands = []
         for cmd in self.REQUIRED_ALFRED_COMMANDS:
@@ -135,7 +135,7 @@ class ProjectValidator:
         if missing_commands:
             missing_list = ", ".join(missing_commands)
             # @SPEC:ERROR-HANDLING-001 | Clear error messages upon missing files
-            # @CODE:INIT-004:ERROR-MESSAGE | Clear reporting of missing Alfred command files
+            # @CODE:INIT-VALIDATOR-001:ERROR-MESSAGE | Clear reporting of missing Alfred command files
             raise ValidationError(
                 f"Required Alfred command files not found: {missing_list}"
             )
