@@ -1,15 +1,19 @@
 #!/usr/bin/env python3
+# @CODE:OFFLINE-001 | SPEC: SPEC-OFFLINE-SUPPORT-001 | TEST: tests/unit/test_network_detection.py
 """Project metadata utilities
 
 Project information inquiry (language, Git, SPEC progress, etc.)
+
+Network detection and caching support:
+- is_network_available(): Check network connectivity with timeout
+- get_package_version_info(): Get package version with offline cache support
 """
 
 import json
+import signal
 import socket
 import subprocess
 from contextlib import contextmanager
-
-from .timeout import CrossPlatformTimeout, TimeoutError as PlatformTimeoutError
 from pathlib import Path
 from typing import Any
 
@@ -98,7 +102,7 @@ def timeout_handler(seconds: int):
     try:
         yield
     finally:
-        timeout.cancel()  # Disable alarm
+        signal.alarm(0)  # Disable alarm
         signal.signal(signal.SIGALRM, old_handler)
 
 
@@ -607,7 +611,7 @@ def get_package_version_info(cwd: str = ".") -> dict[str, Any]:
         else:
             # Skip caching if module can't be loaded
             version_cache_class = None
-    except (ImportError, OSError) as e:
+    except (ImportError, OSError):
         # Graceful degradation: skip caching on import errors
         version_cache_class = None
 
