@@ -9,8 +9,8 @@ from rich.console import Console
 console = Console()
 
 MOAI_BANNER = """
-███╗   ███╗ ██████╗  █████╗ ██╗       █████╗ ██████╗ ██╗  ██╗
-████╗ ████║██╔═══██╗██╔══██╗██║      ██╔══██╗██╔══██╗██║ ██╔╝
+███╗   ███╗          █████╗ ██╗       █████╗ ██████╗ ██╗  ██╗
+████╗ ████║ ██████╗ ██╔══██╗██║      ██╔══██╗██╔══██╗██║ ██╔╝
 ██╔████╔██║██║   ██║███████║██║█████╗███████║██║  ██║█████╔╝
 ██║╚██╔╝██║██║   ██║██╔══██║██║╚════╝██╔══██║██║  ██║██╔═██╗
 ██║ ╚═╝ ██║╚██████╔╝██║  ██║██║      ██║  ██║██████╔╝██║  ██╗
@@ -33,10 +33,10 @@ def print_banner(version: str = "0.3.0") -> None:
 
 def print_welcome_message() -> None:
     """Print the welcome message"""
-    console.print("[cyan bold]🚀 Welcome to MoAI-ADK Project Initialization![/cyan bold]\n")
+    console.print(
+        "[cyan bold]🚀 Welcome to MoAI-ADK Project Initialization![/cyan bold]\n"
+    )
     console.print(
         "[dim]This wizard will guide you through setting up your MoAI-ADK project.[/dim]"
     )
-    console.print(
-        "[dim]You can press Ctrl+C at any time to cancel.\n[/dim]"
-    )
+    console.print("[dim]You can press Ctrl+C at any time to cancel.\n[/dim]")
